@@ -55,7 +55,7 @@ suite('searchPageTestSuite', () => {
     await initializePage();
     // Verify the title is in the page.
     const title = strictQuery('.page-title', page!.shadowRoot, HTMLElement);
-    assertEquals('Send feedback', title.textContent!.trim());
+    assertEquals('Send feedback', title.textContent.trim());
 
     // Verify the iframe is in the page.
     const untrustedFrame =
@@ -74,13 +74,13 @@ suite('searchPageTestSuite', () => {
     // Verify the descriptionTitle is in the page.
     const descriptionTitle =
         strictQuery('#descriptionTitle', page!.shadowRoot, HTMLElement);
-    assertEquals('Description', descriptionTitle.textContent!.trim());
+    assertEquals('Description', descriptionTitle.textContent.trim());
 
     // Verify the feedback writing guidance link is in the page.
     const writingGuidanceLink = strictQuery(
         '#feedbackWritingGuidance', page!.shadowRoot, HTMLAnchorElement);
     assertEquals(
-        'Tips on writing feedback', writingGuidanceLink.textContent!.trim());
+        'Tips on writing feedback', writingGuidanceLink.textContent.trim());
     assertEquals('_blank', writingGuidanceLink.target);
     assertEquals(
         'https://support.google.com/chromebook/answer/2982029',
@@ -94,7 +94,7 @@ suite('searchPageTestSuite', () => {
     // Verify the continue button is in the page.
     const buttonContinue =
         strictQuery('#buttonContinue', page!.shadowRoot, CrButtonElement);
-    assertEquals('Continue', buttonContinue.textContent!.trim());
+    assertEquals('Continue', buttonContinue.textContent.trim());
   });
 
   /**
@@ -399,7 +399,7 @@ suite('searchPageTestSuite', () => {
 
     // Verify that the message is visible now.
     assertTrue(isVisible(errorMsg));
-    assertEquals('Description is required', errorMsg.textContent!.trim());
+    assertEquals('Description is required', errorMsg.textContent.trim());
     // Verify that the textarea received focus again.
     assertEquals(getDeepActiveElement(), textInput);
 
