@@ -6,8 +6,6 @@ import 'chrome://os-settings/os_settings.js';
 
 import type {CrToolbarSearchFieldElement, IronDropdownElement, IronListElement, OsSettingsSearchBoxElement, ToolbarElement} from 'chrome://os-settings/os_settings.js';
 import {OpenWindowProxyImpl, OsSettingsSearchBoxBrowserProxyImpl, personalizationSearchMojom, Router, routes, routesMojom, searchMojom, searchResultIconMojom, setPersonalizationSearchHandlerForTesting, setSettingsSearchHandlerForTesting, settingMojom, setUserActionRecorderForTesting} from 'chrome://os-settings/os_settings.js';
-import {mojoString16ToString, stringToMojoString16} from 'chrome://resources/js/mojo_type_util.js';
-import type {String16} from 'chrome://resources/mojo/mojo/public/mojom/base/string16.mojom-webui.js';
 import {flush} from 'chrome://resources/polymer/v3_0/polymer/polymer_bundled.min.js';
 import {assertDeepEquals, assertEquals, assertFalse, assertNotEquals, assertNull, assertTrue} from 'chrome://webui-test/chai_assert.js';
 import {eventToPromise} from 'chrome://webui-test/test_util.js';
@@ -23,7 +21,7 @@ import {TestOsSettingsSearchBoxBrowserProxy} from './test_os_settings_search_box
 
 suite('<os-settings-search-box>', () => {
   const DEFAULT_RELEVANCE_SCORE: number = 0.5;
-  const DEFAULT_PAGE_HIERARCHY: String16[] = [];
+  const DEFAULT_PAGE_HIERARCHY: string[] = [];
   let toolbar: ToolbarElement;
   let searchBox: OsSettingsSearchBoxElement;
   let field: CrToolbarSearchFieldElement;
@@ -70,8 +68,8 @@ suite('<os-settings-search-box>', () => {
       wasGeneratedFromTextMatch?: boolean,
       relevanceScore?: number): searchMojom.SearchResult {
     return {
-      text: stringToMojoString16(text),
-      canonicalText: stringToMojoString16(text),
+      text: text,
+      canonicalText: text,
       urlPathWithParameters,
       icon: icon ? icon : searchResultIconMojom.SearchResultIcon.MIN_VALUE,
       wasGeneratedFromTextMatch: wasGeneratedFromTextMatch === undefined ?
@@ -97,7 +95,7 @@ suite('<os-settings-search-box>', () => {
           DEFAULT_RELEVANCE_SCORE): personalizationSearchMojom.SearchResult {
     return ({
       searchConceptId: personalizationSearchMojom.SearchConceptId.MIN_VALUE,
-      text: stringToMojoString16(text),
+      text: text,
       relativeUrl,
       relevanceScore,
     });
@@ -716,7 +714,7 @@ suite('<os-settings-search-box>', () => {
           ],
           resultList.items!.map((item: searchMojom.SearchResult) => {
             return {
-              text: mojoString16ToString(item.text),
+              text: item.text,
               relevanceScore: item.relevanceScore,
             };
           }),
