@@ -11,7 +11,6 @@ import {FakeShortcutInputProvider} from 'chrome://resources/ash/common/shortcut_
 import type {KeyEvent} from 'chrome://resources/ash/common/shortcut_input_ui/input_device_settings.mojom-webui.js';
 import {Modifier as ModifierEnum} from 'chrome://resources/ash/common/shortcut_input_ui/shortcut_utils.js';
 import {strictQuery} from 'chrome://resources/ash/common/typescript_utils/strict_query.js';
-import {stringToMojoString16} from 'chrome://resources/js/mojo_type_util.js';
 import {flush} from 'chrome://resources/polymer/v3_0/polymer/polymer_bundled.min.js';
 import type {AcceleratorEditDialogElement} from 'chrome://shortcut-customization/js/accelerator_edit_dialog.js';
 import type {AcceleratorEditViewElement} from 'chrome://shortcut-customization/js/accelerator_edit_view.js';
@@ -90,7 +89,7 @@ suite('acceleratorEditDialogTest', function() {
     assertEquals(3, acceleratorElements.length);
     assertEquals(
         description,
-        dialog.querySelector('#shortcutDescription')!.textContent!.trim());
+        dialog.querySelector('#shortcutDescription')!.textContent.trim());
 
     // Accelerator is sorted, the order is updated to be [c], [ctrl+c],
     // [ctrl+shift+g]
@@ -101,7 +100,7 @@ suite('acceleratorEditDialogTest', function() {
     // [c]
     assertEquals(1, keys1.length);
     assertEquals(
-        'c', keys1[0]!.shadowRoot!.querySelector('#key')!.textContent!.trim());
+        'c', keys1[0]!.shadowRoot!.querySelector('#key')!.textContent.trim());
 
     const accelView2 =
         acceleratorElements[1]!.shadowRoot!.querySelector('accelerator-view');
@@ -111,9 +110,9 @@ suite('acceleratorEditDialogTest', function() {
     assertEquals(2, keys2.length);
     assertEquals(
         'ctrl',
-        keys2[0]!.shadowRoot!.querySelector('#key')!.textContent!.trim());
+        keys2[0]!.shadowRoot!.querySelector('#key')!.textContent.trim());
     assertEquals(
-        'c', keys2[1]!.shadowRoot!.querySelector('#key')!.textContent!.trim());
+        'c', keys2[1]!.shadowRoot!.querySelector('#key')!.textContent.trim());
 
     const accelView3 =
         acceleratorElements[2]!.shadowRoot!.querySelector('accelerator-view');
@@ -123,12 +122,12 @@ suite('acceleratorEditDialogTest', function() {
     assertEquals(3, keys3.length);
     assertEquals(
         'ctrl',
-        keys3[0]!.shadowRoot!.querySelector('#key')!.textContent!.trim());
+        keys3[0]!.shadowRoot!.querySelector('#key')!.textContent.trim());
     assertEquals(
         'shift',
-        keys3[1]!.shadowRoot!.querySelector('#key')!.textContent!.trim());
+        keys3[1]!.shadowRoot!.querySelector('#key')!.textContent.trim());
     assertEquals(
-        'g', keys3[2]!.shadowRoot!.querySelector('#key')!.textContent!.trim());
+        'g', keys3[2]!.shadowRoot!.querySelector('#key')!.textContent.trim());
 
     // Clicking on "Done" button will close the dialog.
     const button = dialog.querySelector<CrButtonElement>('#doneButton');
@@ -192,7 +191,7 @@ suite('acceleratorEditDialogTest', function() {
         acceleratorElements[0]!.shadowRoot!.querySelector(
                                                '#status')!.shadowRoot,
         HTMLDivElement);
-    assertEquals(expectedHintMessage, statusMessageElement.textContent!.trim());
+    assertEquals(expectedHintMessage, statusMessageElement.textContent.trim());
 
     // Re-query the stamped element.
     pendingAccelerator = dialog.querySelector('#pendingAccelerator');
@@ -290,7 +289,7 @@ suite('acceleratorEditDialogTest', function() {
     assertEquals(0, provider.getRestoreDefaultCallCount());
     const fakeResult: AcceleratorResultData = {
       result: AcceleratorConfigResult.kRestoreSuccessWithConflicts,
-      shortcutName: stringToMojoString16('TestDescription'),
+      shortcutName: 'TestDescription',
     };
 
     provider.setFakeRestoreDefaultResult(fakeResult);
@@ -309,7 +308,7 @@ suite('acceleratorEditDialogTest', function() {
     // the error message.
     const fakeConflictResult: AcceleratorResultData = {
       result: AcceleratorConfigResult.kConflict,
-      shortcutName: stringToMojoString16('TestConflictDescription'),
+      shortcutName: 'TestConflictDescription',
     };
     provider.setFakeGetConflictAccelerator(fakeConflictResult);
 
@@ -330,8 +329,7 @@ suite('acceleratorEditDialogTest', function() {
         updatedAcceleratorElements[0]!.shadowRoot!.querySelector(
                                                       '#status')!.shadowRoot,
         HTMLDivElement);
-    assertEquals(
-        expectedErrorMessage, statusMessageElement.textContent!.trim());
+    assertEquals(expectedErrorMessage, statusMessageElement.textContent.trim());
   });
 
   test('RestoreDefaultButtonIgnoreConflict', async () => {
@@ -360,7 +358,7 @@ suite('acceleratorEditDialogTest', function() {
 
     const fakeResult: AcceleratorResultData = {
       result: AcceleratorConfigResult.kRestoreSuccessWithConflicts,
-      shortcutName: stringToMojoString16('TestDescription'),
+      shortcutName: 'TestDescription',
     };
 
     provider.setFakeRestoreDefaultResult(fakeResult);
@@ -376,7 +374,7 @@ suite('acceleratorEditDialogTest', function() {
     // the error message.
     const fakeConflictResult: AcceleratorResultData = {
       result: AcceleratorConfigResult.kConflict,
-      shortcutName: stringToMojoString16('TestConflictDescription'),
+      shortcutName: 'TestConflictDescription',
     };
     provider.setFakeGetConflictAccelerator(fakeConflictResult);
 
@@ -443,7 +441,7 @@ suite('acceleratorEditDialogTest', function() {
 
     const fakeResult: AcceleratorResultData = {
       result: AcceleratorConfigResult.kRestoreSuccessWithConflicts,
-      shortcutName: stringToMojoString16('TestDescription'),
+      shortcutName: 'TestDescription',
     };
 
     provider.setFakeRestoreDefaultResult(fakeResult);
@@ -459,7 +457,7 @@ suite('acceleratorEditDialogTest', function() {
     // the error message.
     const fakeConflictResult: AcceleratorResultData = {
       result: AcceleratorConfigResult.kConflict,
-      shortcutName: stringToMojoString16('TestConflictDescription'),
+      shortcutName: 'TestConflictDescription',
     };
     provider.setFakeGetConflictAccelerator(fakeConflictResult);
 
@@ -537,7 +535,7 @@ suite('acceleratorEditDialogTest', function() {
 
     const fakeResult: AcceleratorResultData = {
       result: AcceleratorConfigResult.kRestoreSuccessWithConflicts,
-      shortcutName: stringToMojoString16('TestDescription'),
+      shortcutName: 'TestDescription',
     };
 
     provider.setFakeRestoreDefaultResult(fakeResult);
@@ -551,7 +549,7 @@ suite('acceleratorEditDialogTest', function() {
     // the error message.
     const fakeConflictResult: AcceleratorResultData = {
       result: AcceleratorConfigResult.kConflict,
-      shortcutName: stringToMojoString16('TestConflictDescription'),
+      shortcutName: 'TestConflictDescription',
     };
     provider.setFakeGetConflictAccelerator(fakeConflictResult);
 
@@ -584,8 +582,7 @@ suite('acceleratorEditDialogTest', function() {
         updatedAcceleratorElements[0]!.shadowRoot!.querySelector(
                                                       '#status')!.shadowRoot,
         HTMLDivElement);
-    assertEquals(
-        expectedErrorMessage, statusMessageElement.textContent!.trim());
+    assertEquals(expectedErrorMessage, statusMessageElement.textContent.trim());
   });
 
   test('FilterDisabledAccelerators', async () => {
@@ -794,8 +791,7 @@ suite('acceleratorEditDialogTest', function() {
     // Expect "No shortcut assigned" message is shown when there's no enabled
     // accelerators in the dialog.
     assertTrue(!!noShortcutAssigned);
-    assertEquals(
-        'No shortcut assigned', noShortcutAssigned.textContent!.trim());
+    assertEquals('No shortcut assigned', noShortcutAssigned.textContent.trim());
 
     // Click add button, ViewState change to ADD.
     const addButton =
