@@ -45,6 +45,10 @@ function getShowMoreButton(): CrButtonElement|null {
   return $$<CrButtonElement>(mostVisited, '#showMore');
 }
 
+function getShowLessButton(): CrButtonElement|null {
+  return $$<CrButtonElement>(mostVisited, '#showLess');
+}
+
 function assertTileLength(length: number) {
   assertEquals(length, queryTiles().length);
 }
@@ -100,6 +104,8 @@ function createBrowserProxy() {
   handler.setResultFor('updateMostVisitedTile', Promise.resolve({
     success: true,
   }));
+  handler.setResultFor(
+      'getMostVisitedExpandedState', Promise.resolve({isExpanded: false}));
 }
 
 class FakeMediaQueryList extends EventTarget implements MediaQueryList {
@@ -161,14 +167,14 @@ function leaveUrlInput() {
 interface SetUpTestOptions {
   singleRow: boolean;
   reflowOnOverflow: boolean;
-  enableShowMoreButton: boolean;
+  expandableTilesEnabled: boolean;
 }
 
 function setUpTest(providedOptions: Partial<SetUpTestOptions> = {}) {
   const defaultOptions = {
     singleRow: false,
     reflowOnOverflow: false,
-    enableShowMoreButton: false,
+    expandableTilesEnabled: false,
   };
   const options = {...defaultOptions, ...providedOptions};
   document.body.innerHTML = window.trustedTypes!.emptyHTML;
@@ -179,8 +185,8 @@ function setUpTest(providedOptions: Partial<SetUpTestOptions> = {}) {
   mostVisited = new MostVisitedElement();
   mostVisited.singleRow = options.singleRow;
   mostVisited.reflowOnOverflow = options.reflowOnOverflow;
-  if (options.enableShowMoreButton) {
-    mostVisited.setAttribute('enable-show-more-button', '');
+  if (options.expandableTilesEnabled) {
+    mostVisited.setAttribute('expandable-tiles-enabled', '');
   }
   document.body.appendChild(mostVisited);
   assertEquals(1, handler.getCallCount('updateMostVisitedInfo'));
@@ -282,44 +288,293 @@ suite('ShowAddButton', () => {
       });
 });
 
-suite('ShowMoreButton', () => {
+suite('ExpandableTiles', () => {
   suiteSetup(() => {
     loadTimeData.overrideValues({
       maxTilesBeforeShowMore: MAX_TILES_BEFORE_SHOW_MORE,
     });
   });
 
+  test('initializes isExpanded to true from pref', async () => {
+    createBrowserProxy();
+    handler.setResultFor(
+        'getMostVisitedExpandedState', Promise.resolve({isExpanded: true}));
+    createWindowProxy();
+
+    mostVisited = new MostVisitedElement();
+    mostVisited.setAttribute('expandable-tiles-enabled', '');
+    document.body.appendChild(mostVisited);
+    await wide();
+
+    await handler.whenCalled('getMostVisitedExpandedState');
+    await microtasksFinished();
+    await addTiles(MAX_TILES_BEFORE_SHOW_MORE + 1);
+    assertTrue(mostVisited['showAll_']);
+    assertTrue(isVisible(getShowLessButton()));
+    assertFalse(isVisible(getShowMoreButton()));
+  });
+
   test('Show more button is shown with 6 or more tiles', async () => {
-    await setUpTest({reflowOnOverflow: true, enableShowMoreButton: true});
+    await setUpTest({reflowOnOverflow: true, expandableTilesEnabled: true});
     await addTiles(MAX_TILES_BEFORE_SHOW_MORE + 1);
     assertTrue(isVisible(getShowMoreButton()));
     assertAddShortcutHidden();
     assertHiddenTileLength(0);
   });
 
-  test('Show more button is hidden with 5 or fewer tiles', async () => {
-    await setUpTest({reflowOnOverflow: true, enableShowMoreButton: true});
-    await addTiles(MAX_TILES_BEFORE_SHOW_MORE);
-    assertFalse(isVisible(getShowMoreButton()));
-    assertAddShortcutShown();
-  });
+  test(
+      'Show more and show less buttons are hidden with 5 or fewer tiles',
+      async () => {
+        await setUpTest({reflowOnOverflow: true, expandableTilesEnabled: true});
+        await addTiles(MAX_TILES_BEFORE_SHOW_MORE);
+        assertFalse(isVisible(getShowMoreButton()));
+        assertFalse(isVisible(getShowLessButton()));
+        assertAddShortcutShown();
+      });
 
   test(
-      'Clicking the show more button shows all tiles and hides the button',
+      'When the number of tiles is 6, toggle between show more and show less',
       async () => {
-        await setUpTest({reflowOnOverflow: true, enableShowMoreButton: true});
-        await addTiles(MAX_TILES_BEFORE_SHOW_MORE + 2);  // 7 tiles.
+        await setUpTest({reflowOnOverflow: true, expandableTilesEnabled: true});
+        await addTiles(MAX_TILES_BEFORE_SHOW_MORE + 1);
         const showMoreButton = getShowMoreButton();
         assertTrue(isVisible(showMoreButton));
         assertAddShortcutHidden();
-        assertHiddenTileLength(1);  // 7 tiles, 6 visible, so 1 hidden.
+        assertHiddenTileLength(0);
 
+        // Click "Show more", expect "Show less" and "Add shortcut" to be shown.
         showMoreButton!.click();
+        const isExpanded =
+            await handler.whenCalled('setMostVisitedExpandedState');
+        assertTrue(isExpanded);
+        handler.resetResolver('setMostVisitedExpandedState');
         await microtasksFinished();
 
         assertFalse(isVisible(getShowMoreButton()));
+        assertTrue(isVisible(getShowLessButton()));
         assertAddShortcutShown();
         assertHiddenTileLength(0);
+
+        // Click "Show less", "Show more" shown and "Add shortcut" hidden
+        const ShowLessButton = getShowLessButton();
+        ShowLessButton!.click();
+        const isExpanded2 =
+            await handler.whenCalled('setMostVisitedExpandedState');
+        assertFalse(isExpanded2);
+        await microtasksFinished();
+
+        assertTrue(isVisible(getShowMoreButton()));
+        assertFalse(isVisible(getShowLessButton()));
+        assertAddShortcutHidden();
+        assertHiddenTileLength(0);
+      });
+
+  test('clicking show more shows all tiles and show less button', async () => {
+    await setUpTest({reflowOnOverflow: true, expandableTilesEnabled: true});
+    await addTiles(MAX_TILES_BEFORE_SHOW_MORE + 2);  // 7 tiles.
+    const showMoreButton = getShowMoreButton();
+    assertTrue(isVisible(showMoreButton));
+    assertAddShortcutHidden();
+    assertHiddenTileLength(1);  // 7 tiles, 6 visible, so 1 hidden.
+
+    showMoreButton!.click();
+    await microtasksFinished();
+
+    assertFalse(isVisible(getShowMoreButton()));
+    assertTrue(isVisible(getShowLessButton()));
+    assertAddShortcutShown();
+    assertHiddenTileLength(0);
+  });
+
+  test('clicking show less hides tiles and show more button', async () => {
+    await setUpTest({reflowOnOverflow: true, expandableTilesEnabled: true});
+    await addTiles(MAX_TILES_BEFORE_SHOW_MORE + 2);  // 7 tiles.
+    const showMoreButton = getShowMoreButton();
+    const showLessButton = getShowLessButton();
+
+    assertTrue(isVisible(showMoreButton));
+    assertFalse(isVisible(showLessButton));
+    assertAddShortcutHidden();
+    assertHiddenTileLength(1);
+
+    // Click "Show more".
+    showMoreButton!.click();
+    await microtasksFinished();
+
+    assertFalse(isVisible(showMoreButton));
+    assertTrue(isVisible(showLessButton));
+    assertAddShortcutShown();
+    assertHiddenTileLength(0);
+
+    // Click "Show less".
+    showLessButton!.click();
+    await microtasksFinished();
+
+    assertTrue(isVisible(showMoreButton));
+    assertFalse(isVisible(showLessButton));
+    assertAddShortcutHidden();
+    assertHiddenTileLength(1);
+  });
+
+  test('clicking show less with max tiles correctly collapses UI', async () => {
+    // This test reproduces a bug where having max tiles (10) would cause the
+    // "Show less" button to appear on a new row, and clicking it would fail
+    // to collapse the layout correctly, leaving a blank second row.
+    await setUpTest({reflowOnOverflow: true, expandableTilesEnabled: true});
+    await addTiles(MAX_TILES_FOR_CUSTOM_LINKS);  // 10 tiles.
+
+    const showMoreButton = getShowMoreButton();
+    assertTrue(isVisible(showMoreButton));
+
+    // Click "Show more" to expand.
+    showMoreButton!.click();
+    await microtasksFinished();
+
+    // Verify the expanded layout. With 10 tiles and a "Show less" button,
+    // we expect 3 rows on a wide screen (5 columns).
+    const showLessButton = getShowLessButton();
+    assertTrue(isVisible(showLessButton));
+    assertHiddenTileLength(0);
+    const expandedItems =
+        queryAll<HTMLElement>('.tile:not([hidden]), #showLess');
+    assertEquals(MAX_TILES_FOR_CUSTOM_LINKS + 1, expandedItems.length);
+    const firstRowTop = expandedItems[0]!.offsetTop;
+    const secondRowTop = expandedItems[5]!.offsetTop;
+    const thirdRowTop = expandedItems[10]!.offsetTop;
+    assertNotEquals(firstRowTop, secondRowTop);
+    assertNotEquals(secondRowTop, thirdRowTop);
+    const expandedHeight = mostVisited.$.container.offsetHeight;
+
+    // Click "Show less" to collapse.
+    showLessButton!.click();
+    await microtasksFinished();
+
+    // Verify the collapsed layout. We should have 2 rows with 6 tiles and
+    // the "Show more" button.
+    assertTrue(isVisible(getShowMoreButton()));
+    // There are 10 tiles total. When collapsed, 6 are visible. 4 are hidden.
+    assertHiddenTileLength(4);
+    const collapsedItems =
+        queryAll<HTMLElement>('.tile:not([hidden]), #showMore');
+    assertEquals(MAX_TILES_BEFORE_SHOW_MORE + 1 + 1, collapsedItems.length);
+    const collapsedHeight = mostVisited.$.container.offsetHeight;
+    assertNotEquals(
+        expandedHeight, collapsedHeight,
+        'Collapsed layout should be shorter than expanded layout');
+  });
+
+  test(
+      'show less button on first row with 8 tiles and custom links disabled',
+      async () => {
+        await setUpTest({
+          singleRow: true,
+          reflowOnOverflow: true,
+          expandableTilesEnabled: true,
+        });
+        await addTiles(8, /*customLinksEnabled=*/ false);
+
+        const showMoreButton = getShowMoreButton();
+        assertTrue(isVisible(showMoreButton));
+
+        // Click "Show more" to expand.
+        showMoreButton!.click();
+        await microtasksFinished();
+
+        // We expect 1 row with 8 tiles and a "Show less" button.
+        const showLessButton = getShowLessButton();
+        assertTrue(isVisible(showLessButton));
+        assertHiddenTileLength(0);
+        const expandedItems =
+            queryAll<HTMLElement>('.tile:not([hidden]), #showLess');
+        assertEquals(8 + 1, expandedItems.length);
+        const firstItemTop = expandedItems[0]!.offsetTop;
+        for (const item of expandedItems) {
+          assertEquals(firstItemTop, item.offsetTop);
+        }
+        assertEquals(1, rowCount());
+      });
+
+  test(
+      'show more and show less buttons do not move during drag and drop',
+      async () => {
+        await setUpTest({reflowOnOverflow: true, expandableTilesEnabled: true});
+        await addTiles(MAX_TILES_BEFORE_SHOW_MORE + 2);  // 7 tiles.
+
+        const showMoreButton = getShowMoreButton()!;
+        assertTrue(isVisible(showMoreButton));
+        const showMoreButtonRect = showMoreButton.getBoundingClientRect();
+
+        // Simulate drag and drop.
+        const tiles = queryTiles();
+        const first = tiles[0]!;
+        const second = tiles[1]!;
+        const firstRect = first.getBoundingClientRect();
+        const secondRect = second.getBoundingClientRect();
+        first.dispatchEvent(new DragEvent('dragstart', {
+          clientX: firstRect.x + firstRect.width / 2,
+          clientY: firstRect.y + firstRect.height / 2,
+        }));
+        await microtasksFinished();
+
+        // Check position of "Show more" button immediately after drag starts.
+        let newShowMoreButtonRect = showMoreButton.getBoundingClientRect();
+        assertDeepEquals(showMoreButtonRect, newShowMoreButtonRect);
+
+        const reorderCalled = handler.whenCalled('reorderMostVisitedTile');
+        document.dispatchEvent(new DragEvent('drop', {
+          clientX: secondRect.x + 1,
+          clientY: secondRect.y + 1,
+        }));
+        document.dispatchEvent(new DragEvent('dragend', {
+          clientX: secondRect.x + 1,
+          clientY: secondRect.y + 1,
+        }));
+        await mostVisited.updateComplete;
+        await reorderCalled;
+
+        // Check position of "Show more" button.
+        newShowMoreButtonRect = showMoreButton.getBoundingClientRect();
+        assertDeepEquals(showMoreButtonRect, newShowMoreButtonRect);
+
+        // Expand to show "Show less" button.
+        showMoreButton.click();
+        await microtasksFinished();
+
+        const showLessButton = getShowLessButton()!;
+        assertTrue(isVisible(showLessButton));
+        const showLessButtonRect = showLessButton.getBoundingClientRect();
+
+        // Simulate another drag and drop.
+        const newTiles = queryTiles();
+        const newFirst = newTiles[0]!;
+        const newSecond = newTiles[1]!;
+        const newFirstRect = newFirst.getBoundingClientRect();
+        const newSecondRect = newSecond.getBoundingClientRect();
+        newFirst.dispatchEvent(new DragEvent('dragstart', {
+          clientX: newFirstRect.x + newFirstRect.width / 2,
+          clientY: newFirstRect.y + newFirstRect.height / 2,
+        }));
+        await microtasksFinished();
+
+        // Check position of "Show less" button immediately after drag starts.
+        let newShowLessButtonRect = showLessButton.getBoundingClientRect();
+        assertDeepEquals(showLessButtonRect, newShowLessButtonRect);
+
+        const reorderCalledAgain = handler.whenCalled('reorderMostVisitedTile');
+        document.dispatchEvent(new DragEvent('drop', {
+          clientX: newSecondRect.x + 1,
+          clientY: newSecondRect.y + 1,
+        }));
+        document.dispatchEvent(new DragEvent('dragend', {
+          clientX: newSecondRect.x + 1,
+          clientY: newSecondRect.y + 1,
+        }));
+        await mostVisited.updateComplete;
+        await reorderCalledAgain;
+
+        // Check position of "Show less" button.
+        newShowLessButtonRect = showLessButton.getBoundingClientRect();
+        assertDeepEquals(showLessButtonRect, newShowLessButtonRect);
       });
 });
 
