@@ -57,6 +57,27 @@ IN_PROC_BROWSER_TEST_F(ZeroStatePromoChipsUiV2Test, AllTests) {
       "runMochaSuite('ChipsUiV2Test');");
 }
 
+class ZeroStatePromoChipsUiV3Test : public ZeroStatePromoBrowserTest {
+ protected:
+  ZeroStatePromoChipsUiV3Test() {
+    feature_list_.InitAndEnableFeatureWithParameters(
+        feature_engagement::kIPHExtensionsZeroStatePromoFeature,
+        {{feature_engagement::kIPHExtensionsZeroStatePromoVariantParam.name,
+          feature_engagement::kIPHExtensionsZeroStatePromoVariantParam.GetName(
+              feature_engagement::IPHExtensionsZeroStatePromoVariant::
+                  kCustomUiChipIphV3)}});
+  }
+
+ private:
+  base::test::ScopedFeatureList feature_list_;
+};
+
+IN_PROC_BROWSER_TEST_F(ZeroStatePromoChipsUiV3Test, AllTests) {
+  ZeroStatePromoBrowserTest::RunTest(
+      "extensions_zero_state/zero_state_promo_app_test.js",
+      "runMochaSuite('ChipsUiV3Test');");
+}
+
 class ZeroStatePromoPlainLinkUiTest : public ZeroStatePromoBrowserTest {
  protected:
   ZeroStatePromoPlainLinkUiTest() : ZeroStatePromoBrowserTest() {
