@@ -97,6 +97,24 @@ class ApiTests extends ApiTestFixtureBase {
     this.host.setAudioDucking(false);
   }
 
+  async testPopupOpens() {
+    const link = document.createElement('a');
+    link.setAttribute('href', 'https://www.chromium.org');
+
+    // Attach a click listener to force opening as a popup with specific
+    // dimensions. Including features like width/height forces a new window
+    // instead of a tab.
+    link.addEventListener('click', (e) => {
+      e.preventDefault();
+      window.open(
+          link.getAttribute('href')!, 'popup_window',
+          'width=500,height=500,scrollbars=yes,resizable=yes');
+    });
+
+    document.body.appendChild(link);
+    link.click();
+  }
+
   async testCreateTabByClickingOnLinkDaisyChains() {
     assertDefined(this.host.getFocusedTabStateV2);
     assertDefined(this.host.getPinnedTabs);
@@ -135,6 +153,11 @@ class ApiTests extends ApiTestFixtureBase {
     await sleep(500);
   }
 
+  async testOpenPasswordManagerSettingsPage() {
+    assertDefined(this.host.openPasswordManagerSettingsPage);
+    this.host.openPasswordManagerSettingsPage();
+  }
+
   async testGetPanelStateAttached() {
     assertDefined(this.host.getPanelState);
     // getPanelState and notifyPanelWillOpen should signal the ATTACHED state.
@@ -182,6 +205,65 @@ class ApiTests extends ApiTestFixtureBase {
     //    PanelStateKind.ATTACHED);
   }
 
+  async testCanAttachPanelSidePanel() {
+    assertDefined(this.host.getPanelState);
+    assertDefined(this.host.canAttachPanel);
+
+    const panelStates = observeSequence(this.host.getPanelState());
+    await panelStates.waitFor(state => state.kind === PanelStateKind.ATTACHED);
+
+    await observeSequence(this.host.canAttachPanel()).waitForValue(false);
+  }
+
+  async testCanAttachPanelDetached() {
+    assertDefined(this.host.getPanelState);
+    assertDefined(this.host.detachPanel);
+    assertDefined(this.host.canAttachPanel);
+
+    const panelStates = observeSequence(this.host.getPanelState());
+    await panelStates.waitFor(state => state.kind === PanelStateKind.ATTACHED);
+
+    this.host.detachPanel();
+    await panelStates.waitFor(state => state.kind === PanelStateKind.DETACHED);
+
+    await observeSequence(this.host.canAttachPanel()).waitForValue(true);
+  }
+
+  async testCanAttachPanelDetachedTabClosed() {
+    assertDefined(this.host.getPanelState);
+    assertDefined(this.host.detachPanel);
+    assertDefined(this.host.canAttachPanel);
+
+    const panelStates = observeSequence(this.host.getPanelState());
+    await panelStates.waitFor(state => state.kind === PanelStateKind.ATTACHED);
+
+    this.host.detachPanel();
+    await panelStates.waitFor(state => state.kind === PanelStateKind.DETACHED);
+
+    const canAttachSeq = observeSequence(this.host.canAttachPanel());
+    await canAttachSeq.waitForValue(true);
+
+    // Wait for C++ to close the tab.
+    await this.advanceToNextStep();
+
+    await canAttachSeq.waitForValue(false);
+  }
+
+  async testAttachPanel() {
+    assertDefined(this.host.getPanelState);
+    assertDefined(this.host.detachPanel);
+    assertDefined(this.host.attachPanel);
+
+    const panelStates = observeSequence(this.host.getPanelState());
+    await panelStates.waitFor(state => state.kind === PanelStateKind.ATTACHED);
+
+    this.host.detachPanel();
+    await panelStates.waitFor(state => state.kind === PanelStateKind.DETACHED);
+
+    this.host.attachPanel();
+    await panelStates.waitFor(state => state.kind === PanelStateKind.ATTACHED);
+  }
+
   async testMultiplePanelsDetachedAndFloating() {
     assertDefined(this.host.getPanelState);
     assertDefined(this.host.detachPanel);
@@ -728,6 +810,36 @@ class ApiTests extends ApiTestFixtureBase {
     assertFalse(await defaultTabContextState.next() as boolean);
   }
 
+  async testPinOnBind() {
+    assertDefined(this.host.getDefaultTabContextPermissionState);
+    const defaultTabContextState =
+        observeSequence(this.host.getDefaultTabContextPermissionState());
+    assertTrue(await defaultTabContextState.next() as boolean);
+    assertDefined(this.host.getPinnedTabs);
+    const pinnedTabsUpdates = observeSequence(this.host.getPinnedTabs());
+
+    // The active tab should be automatically pinned on bind.
+    const pinnedTabs =
+        await pinnedTabsUpdates.waitFor(tabs => tabs.length === 1);
+    const activeTabId = this.getActiveTabId();
+    assertEquals(pinnedTabs[0]!.tabId, activeTabId);
+  }
+
+  async testNoPinOnBindWhenSettingOff() {
+    assertDefined(this.host.getPinnedTabs);
+    const pinnedTabsUpdates = observeSequence(this.host.getPinnedTabs());
+
+    // The initial value is an empty array.
+    const initialTabs = await pinnedTabsUpdates.next();
+    assertEquals(0, initialTabs.length);
+
+    // Wait briefly to ensure no unexpected updates arrive.
+    await sleep(200);
+    assertTrue(
+        pinnedTabsUpdates.isEmpty(),
+        'Pinned tabs should remain empty when auto-pinning is disabled.');
+  }
+
   async testGetOsHotkeyState() {
     assertDefined(this.host.getOsHotkeyState);
     const osHotkeyState = observeSequence(this.host.getOsHotkeyState());
@@ -1407,10 +1519,12 @@ class ApiTests extends ApiTestFixtureBase {
     assertDefined(this.host.getContextFromTab);
     assertDefined(this.host.pinTabs);
     assertDefined(this.host.getPinnedTabs);
+    assertDefined(this.host.unpinTabs);
 
     // Fail getContextFromTab due to no tab context permission not granted.
     await this.host.setTabContextPermissionState(false);
     const tabId: string = this.getFocusedTabId();
+    await this.host.unpinTabs([tabId]);  // Unpin required for multi-instance.
     await assertRejects(this.host.getContextFromTab(tabId, {}), {
       withErrorMessage: 'tabContext failed: permission denied:' +
           ' context permission not enabled',
@@ -1972,7 +2086,7 @@ class ApiTests extends ApiTestFixtureBase {
         assertTrue(context.tabId!.length > 0);
         assertDefined(context.frameUrl);
         assertTrue(context.frameUrl!.length > 0);
-        assertEquals(context.parts.length, 5);
+        assertEquals(context.parts.length, 6);
 
         const part1 = context.parts[0]!;
         assertDefined(part1.data);
@@ -2005,6 +2119,12 @@ class ApiTests extends ApiTestFixtureBase {
         const pdfText = await new Response(part5.pdf!.pdfData!).text();
         assertEquals(pdfText, 'pdf');
 
+        const part6 = context.parts[5]!;
+        assertDefined(part6.tabContext);
+        assertDefined(part6.tabContext!.tabData);
+        assertEquals(part6.tabContext!.tabData!.tabId, '1');
+        assertEquals(part6.tabContext!.tabData!.windowId, '2');
+        assertEquals(part6.tabContext!.tabData!.url, 'https://google.com/');
         resolve();
       });
     });
@@ -2179,11 +2299,9 @@ class ApiTests extends ApiTestFixtureBase {
     assertDefined(this.host.getActOnWebCapability);
     const actOnWebCapabilitySequence =
         observeSequence(this.host.getActOnWebCapability());
-    let actOnWebCapability = await actOnWebCapabilitySequence.next();
-    assertEquals(actOnWebCapability, true);
+    await actOnWebCapabilitySequence.waitForValue(true);
     await this.advanceToNextStep();
-    actOnWebCapability = await actOnWebCapabilitySequence.next();
-    assertEquals(actOnWebCapability, false);
+    await actOnWebCapabilitySequence.waitForValue(false);
   }
 
   async testPanelWillOpenBeforeClientReady() {
@@ -2191,6 +2309,45 @@ class ApiTests extends ApiTestFixtureBase {
     assertEquals('test_conversation_id', openData.conversationId);
   }
 
+  async testPanelWillOpenHasRecentlyActiveConversations() {
+    assertDefined(this.host.registerConversation);
+
+    if (this.testParams === 'instance1') {
+      await this.host.registerConversation(
+          {conversationTitle: 'Title 1', conversationId: 'convo1'});
+    } else if (this.testParams === 'instance2') {
+      await this.host.registerConversation(
+          {conversationTitle: 'Title 2', conversationId: 'convo2'});
+    } else if (this.testParams === 'instance3') {
+      await this.host.registerConversation(
+          {conversationTitle: 'Title 3', conversationId: 'convo3'});
+    } else if (this.testParams === 'instance4') {
+      await this.host.registerConversation(
+          {conversationTitle: 'Title 4', conversationId: 'convo4'});
+    } else if (this.testParams === 'verify') {
+      const openData = await observeSequence(this.client.panelOpenData).next();
+      assertDefined(openData.recentlyActiveConversations);
+      // Expecting convo4, convo2, convo3 (based on activation order in C++
+      // test)
+      assertEquals(3, openData.recentlyActiveConversations.length);
+      assertEquals(
+          'convo4', openData.recentlyActiveConversations[0]?.conversationId);
+      assertEquals(
+          'Title 4',
+          openData.recentlyActiveConversations[0]?.conversationTitle);
+      assertEquals(
+          'convo2', openData.recentlyActiveConversations[1]?.conversationId);
+      assertEquals(
+          'Title 2',
+          openData.recentlyActiveConversations[1]?.conversationTitle);
+      assertEquals(
+          'convo3', openData.recentlyActiveConversations[2]?.conversationId);
+      assertEquals(
+          'Title 3',
+          openData.recentlyActiveConversations[2]?.conversationTitle);
+    }
+  }
+
   private async closePanelAndWaitUntilInactive() {
     assertDefined(this.host.closePanel);
     await this.host.closePanel();
