@@ -18,7 +18,7 @@ import {assertDeepEquals, assertEquals, assertFalse, assertTrue} from 'chrome://
 import type {MetricsTracker} from 'chrome://webui-test/metrics_test_support.js';
 import {fakeMetricsPrivate} from 'chrome://webui-test/metrics_test_support.js';
 import {TestMock} from 'chrome://webui-test/test_mock.js';
-import {$$, microtasksFinished} from 'chrome://webui-test/test_util.js';
+import {$$, isVisible, microtasksFinished} from 'chrome://webui-test/test_util.js';
 
 type Constructor<T> = new (...args: any[]) => T;
 type Installer<T> = (instance: T) => void;
@@ -64,7 +64,8 @@ suite('NewTabFooterAppTest', () => {
 
     element = document.createElement('new-tab-footer-app');
     document.body.appendChild(element);
-    callbackRouter.attachedTabStateUpdated(ntpType);
+    callbackRouter.attachedTabStateUpdated(
+        ntpType, /*canCustomizeChrome=*/ true);
     await callbackRouter.$.flushForTesting();
     await microtasksFinished();
   }
@@ -125,7 +126,8 @@ suite('NewTabFooterAppTest', () => {
           test(`Change NTP type to ${pageType}`, async () => {
             // Act.
             const fooName = 'foo';
-            callbackRouter.attachedTabStateUpdated(pageType);
+            callbackRouter.attachedTabStateUpdated(
+                pageType, /*canCustomizeChrome=*/ true);
             callbackRouter.setNtpExtensionName(fooName);
             await callbackRouter.$.flushForTesting();
 
@@ -400,7 +402,8 @@ suite('NewTabFooterAppTest', () => {
               `setting ntp type ${pageType} shows customize button ${expected}`,
               async () => {
                 // Act.
-                callbackRouter.attachedTabStateUpdated(pageType);
+                callbackRouter.attachedTabStateUpdated(
+                    pageType, /*canCustomizeChrome=*/ true);
                 await callbackRouter.$.flushForTesting();
 
                 // Assert.
@@ -408,6 +411,21 @@ suite('NewTabFooterAppTest', () => {
                 assertEquals(!!buttons, expected);
               });
         });
+
+    test('button hidden when `canCustomizeChrome` is false', async () => {
+      // Arrange.
+      const button = getCustomizeButton();
+      assertTrue(isVisible(button));
+
+      // Act.
+      callbackRouter.attachedTabStateUpdated(
+          NewTabPageType.kExtension, /*canCustomizeChrome=*/ false);
+      await callbackRouter.$.flushForTesting();
+
+      // Assert.
+      const buttons = $$(element, '#customizeButtons');
+      assertFalse(!!buttons);
+    });
   });
 
   suite('Misc', () => {
