@@ -16,8 +16,9 @@ suite('NewTabPageContextualEntrypointAndCarouselTest', () => {
   });
 
   test('voice search click emits event', async () => {
-    element.realboxLayoutMode = 'TallTopContext';
+    element.searchboxLayoutMode = 'TallTopContext';
     element.showDropdown = true;
+    element.showVoiceSearch = true;
     await microtasksFinished();
 
     const whenOpenVoiceSearch = eventToPromise('open-voice-search', element);
