@@ -2,7 +2,7 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-import {recordBoolean, recordDuration, recordEnumeration, recordLoadDuration, recordOccurrence, recordPerdecage, recordSmallCount, recordSparseValueWithPersistentHash, recordValue} from 'chrome://new-tab-page/new_tab_page.js';
+import {recordBoolean, recordDuration, recordEnumeration, recordLinearValue, recordLoadDuration, recordLogValue, recordOccurrence, recordPerdecage, recordSmallCount, recordSparseValueWithPersistentHash} from 'chrome://new-tab-page/new_tab_page.js';
 import {loadTimeData} from 'chrome://resources/js/load_time_data.js';
 import {assertEquals} from 'chrome://webui-test/chai_assert.js';
 import type {MetricsTracker} from 'chrome://webui-test/metrics_test_support.js';
@@ -48,20 +48,6 @@ suite('NewTabPageMetricsUtilsTest', () => {
     assertEquals(1, metrics.count('foo.metric', 5));
   });
 
-  test('recordValue', () => {
-    recordValue(
-        {
-          metricName: 'foo.metric',
-          type: chrome.metricsPrivate.MetricTypeType.HISTOGRAM_LINEAR,
-          min: 1,
-          max: 10,
-          buckets: 11,
-        },
-        5);
-    assertEquals(1, metrics.count('foo.metric'));
-    assertEquals(1, metrics.count('foo.metric', 5));
-  });
-
   test('recordEnumeration', () => {
     recordEnumeration('foo.metric', 5, 10);
     assertEquals(1, metrics.count('foo.metric'));
@@ -79,4 +65,26 @@ suite('NewTabPageMetricsUtilsTest', () => {
     assertEquals(1, metrics.count('foo.metric'));
     assertEquals(1, metrics.count('foo.metric', true));
   });
+
+  test('recordLogValue', () => {
+    recordLogValue(
+        'foo.metric',
+        /*min=*/ 1,
+        /*max=*/ 10,
+        /*buckets=*/ 11,
+        /*value=*/ 5);
+    assertEquals(1, metrics.count('foo.metric'));
+    assertEquals(1, metrics.count('foo.metric', 5));
+  });
+
+  test('recordLinearValue', () => {
+    recordLinearValue(
+        'foo.metric',
+        /*min=*/ 1,
+        /*max=*/ 10,
+        /*buckets=*/ 11,
+        /*value=*/ 5);
+    assertEquals(1, metrics.count('foo.metric'));
+    assertEquals(1, metrics.count('foo.metric', 5));
+  });
 });
