@@ -3,31 +3,28 @@
 // found in the LICENSE file.
 
 import type {SettingsMenuElement} from 'chrome://settings/settings.js';
-import {pageVisibility} from 'chrome://settings/settings.js';
+import {resetPageVisibilityForTesting} from 'chrome://settings/settings.js';
 import {assertEquals} from 'chrome://webui-test/chai_assert.js';
 
 suite('SettingsMenuInteractiveUITest', () => {
   let settingsMenu: SettingsMenuElement;
 
-  setup(() => {
+  function createMenu() {
     document.body.innerHTML = window.trustedTypes!.emptyHTML;
     settingsMenu = document.createElement('settings-menu');
-    settingsMenu.pageVisibility = pageVisibility;
     document.body.appendChild(settingsMenu);
-  });
+  }
 
   test('focusFirstItem', () => {
-    settingsMenu.pageVisibility = Object.assign({}, pageVisibility || {}, {
-      people: true,
-      autofill: true,
-    });
+    createMenu();
     settingsMenu.focusFirstItem();
     assertEquals(settingsMenu.$.people, settingsMenu.shadowRoot!.activeElement);
 
-    settingsMenu.pageVisibility = Object.assign({}, pageVisibility || {}, {
+    resetPageVisibilityForTesting({
       people: false,
       autofill: true,
     });
+    createMenu();
     settingsMenu.focusFirstItem();
     assertEquals(
         settingsMenu.$.autofill, settingsMenu.shadowRoot!.activeElement);
