@@ -54,6 +54,7 @@ export class TestSyncBrowserProxy extends TestBrowserProxy implements
       'startSignIn',
       'didNavigateToAccountSettingsPage',
       'setSyncDatatype',
+      'recordSigninPendingOffered',
       // </if>
 
       // <if expr="is_chromeos">
@@ -120,6 +121,10 @@ export class TestSyncBrowserProxy extends TestBrowserProxy implements
     this.methodCalled('setSyncDatatype', pref, value);
     return Promise.resolve(PageStatus.CONFIGURE);
   }
+
+  recordSigninPendingOffered(): void {
+    this.methodCalled('recordSigninPendingOffered');
+  }
   // </if>
 
   startSyncingWithEmail(email: string, isDefaultPromoAccount: boolean) {
