@@ -8,6 +8,7 @@ import {MetricsBrowserProxyImpl, NodeStore, playFromSelectionTimeout, ReadAloudN
 import type {Segment} from 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
 import {MockTimer} from 'chrome-untrusted://webui-test/mock_timer.js';
 import {microtasksFinished} from 'chrome-untrusted://webui-test/test_util.js';
+import {assertEquals} from 'chrome-untrusted://webui-test/chai_assert.js';
 
 import {TestMetricsBrowserProxy} from './test_metrics_browser_proxy.js';
 import type {TestReadAloudModelBrowserProxy} from './test_read_aloud_browser_proxy.js';
@@ -57,6 +58,26 @@ export function getItemsInMenu(
   return Array.from(menu.querySelectorAll<HTMLButtonElement>('.dropdown-item'));
 }
 
+function assertCheckMarkVisible(
+    checkMarks: NodeListOf<HTMLElement>, expectedIndex: number): void {
+  checkMarks.forEach((element, index) => {
+    assertEquals(
+        index === expectedIndex ? 'visible' : 'hidden',
+        element.style.visibility);
+  });
+}
+
+export function assertCheckMarksForDropdown(dropdown: HTMLElement): void {
+  const buttons =
+      dropdown.querySelectorAll<HTMLButtonElement>('.dropdown-item');
+  const checkMarks = dropdown.querySelectorAll<HTMLElement>('.check-mark');
+  assertEquals(buttons.length, checkMarks.length);
+  buttons.forEach((button, index) => {
+    button.click();
+    assertCheckMarkVisible(checkMarks, index);
+  });
+}
+
 export function createSpeechErrorEvent(
     utterance: SpeechSynthesisUtterance,
     errorCode: SpeechSynthesisErrorCode): SpeechSynthesisErrorEvent {
@@ -108,36 +129,8 @@ export function createSpeechSynthesisVoice(
       overrides || {});
 }
 
-
-export function setSimpleAxTreeWithText(text: string) {
-  const axTree = {
-    rootId: 1,
-    nodes: [
-      {
-        id: 1,
-        role: 'rootWebArea',
-        htmlTag: '#document',
-        childIds: [2],
-      },
-      {id: 2, role: 'staticText', name: text},
-    ],
-  };
-  chrome.readingMode.setContentForTesting(axTree, [2]);
-}
-
-// TODO: crbug.com/440400392- Merge setSimpleNodeStoreWithText with
-// setSimpleNodeStoreWithTextAndModel
-export function setSimpleNodeStoreWithText(text: string) {
-  const id = 2;
-  chrome.readingMode.getCurrentTextSegments =
-      () => [{nodeId: id, start: 0, length: text.length}];
-  chrome.readingMode.getCurrentTextContent = () => text;
-  chrome.readingMode.getTextContent = () => text;
-  NodeStore.getInstance().setDomNode(document.createTextNode(text), id);
-}
-
-export function setSimpleNodeStoreWithTextAndModel(
-    text: string, model?: TestReadAloudModelBrowserProxy): Node {
+export function setContent(
+    text: string, model: TestReadAloudModelBrowserProxy): Node {
   const id = 2;
   const node = document.createTextNode(text);
   NodeStore.getInstance().setDomNode(node, id);
@@ -149,10 +142,3 @@ export function setSimpleNodeStoreWithTextAndModel(
   }
   return node;
 }
-
-
-// Sets up the simple AX tree and node store with the given text.
-export function setSimpleTreeWithText(text: string) {
-  setSimpleAxTreeWithText(text);
-  setSimpleNodeStoreWithText(text);
-}
